Opinion & Order Search

Sign In

Print

- By Party Name
- By Docket Number
- By Keyword
- Advanced

Use the By Party Name search to locate the Court opinions and orders for a specific party name. The party name can be the name of an individual or organization. Do not include a comma and use only one space to separate names. Search Tips
Party Name:
(Lastname Firstname Middle Initial OR Company Name)
Party Name is required Party Name must contain at least 4 characters
Select Court:

Supreme Court
Court of Appeals
Both

Please select a court
Use the By Docket Number search to locate the Court opinions and orders for a specific case docket number. Choose either Supreme Court or Court of Appeals. Search Tips
Case Docket Number: Case Docket Number must be a valid number less than 999999 Case Docket Number is required
Select Court:

Supreme Court
Court of Appeals

Please select a court
Use the By Keyword search to perform a full text search on all Court opinions and orders based on a specific keyword. Select a search scope and then type the keyword or phrase. Search Tips

Use the Advanced search to locate Court opinions and orders by selecting criteria in the provided fields. The required fields are the Date and Status fields. Both of these fields have default values. The remaining fields are optional. Search Tips
Author:
Panel Member:
Case Type:
Case Nature is required
Lower Court:
Lower Court is required
Status:
Status is required
Date: Beginning date required Invalid date
Through: Invalid date
Color Key:
Case title appears in red for Supreme Court opinions.
Case title appears in blue for Court of Appeals published opinions.
Case title appears in black for Court of Appeals unpublished opinions.
Case title appears in green for orders.
& signifies that the document is the official reported version of the opinion.
Advanced Opinions & Orders Search Results -

- CASE NUMBER
- CASE DETAILS
- DOWNLOAD

- 1
- 315942
- - - ALAN JESPERSON V AUTO CLUB INSURANCE ASSOCIATION
    - Release Date: 9/16/2014
    - Lower Court: MACOMB CIRCUIT COURT
    - COA Opinion - Authored - Published
    - Case Type: Summary Disposition Granted
  - - Judge(s): MTB PMM DAS
    - Lower Court No. 2010-005127-NI
    - View Docket Sheet

- 2
- 315942
- - - ALAN JESPERSON V AUTO CLUB INSURANCE ASSOCIATION
    - Release Date: 9/16/2014
    - Lower Court: MACOMB CIRCUIT COURT
    - COA Opinion - Dissenting
    - Case Type: Summary Disposition Granted
  - - Judge(s): DAS
    - Lower Court No. 2010-005127-NI
    - View Docket Sheet

- 3
- 312325
- - - PEOPLE OF MI V ROLAND HARRY STEVENS
    - Release Date: 9/11/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Published
    - Case Type: Assault w/intent to do GBH
  - - Judge(s): JPH KTW KFH
    - Lower Court No. 12-003163-FC
    - View Docket Sheet

- 4
- 309269
- - - IN RE CONTEMPT OF KELLY MICHELLE DORSEY
    - Release Date: 9/9/2014
    - Lower Court: LIVINGSTON JUVENILE DIVISION
    - COA Opinion - Authored - Published
    - Case Type: Criminal Contempt
  - - Judge(s): KFK JEM KFH
    - Lower Court No. 08-012596-DL
    - View Docket Sheet

- 5
- 311723
- - - MOVIE MANIA METRO INC V GZ DVD'S INC
    - Release Date: 9/9/2014
    - Lower Court: MACOMB CIRCUIT COURT
    - COA Opinion - Authored - Published
    - Case Type: Summary Disposition Granted
  - - Judge(s): PMM MJC HWS
    - Lower Court No. 2011-002876-CB
    - View Docket Sheet

- 6
- 314877
- - - PEOPLE OF MI V CHARLES ALMANDO-MAURICE DUNBAR
    - Release Date: 9/9/2014
    - Lower Court: MUSKEGON CIRCUIT COURT
    - COA Opinion - Authored - Published
    - Case Type: Motion to Suppress Evidence Denied
  - - Judge(s): PMM PDO DBS
    - Lower Court No. 12-062736-FH
    - View Docket Sheet

- 7
- 314877
- - - PEOPLE OF MI V CHARLES ALMANDO-MAURICE DUNBAR
    - Release Date: 9/9/2014
    - Lower Court: MUSKEGON CIRCUIT COURT
    - COA Opinion - Concurring
    - Case Type: Motion to Suppress Evidence Denied
  - - Judge(s): PDO
    - Lower Court No. 12-062736-FH
    - View Docket Sheet

- 8
- 314877
- - - PEOPLE OF MI V CHARLES ALMANDO-MAURICE DUNBAR
    - Release Date: 9/9/2014
    - Lower Court: MUSKEGON CIRCUIT COURT
    - COA Opinion - Dissenting
    - Case Type: Motion to Suppress Evidence Denied
  - - Judge(s): PMM
    - Lower Court No. 12-062736-FH
    - View Docket Sheet

- 9
- 315531
- - - JAMES GARDNER V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Authored - Published
    - Case Type: Tax Tribunal
  - - Judge(s): MJC DSO CDS
    - Lower Court No. 00-434966
    - View Docket Sheet

- 10
- 315531
- - - JAMES GARDNER V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Dissenting
    - Case Type: Tax Tribunal
  - - Judge(s): DSO
    - Lower Court No. 00-434966
    - View Docket Sheet

- 11
- 315684
- - - LIEM NGO V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Authored - Published
    - Case Type: Tax Tribunal
  - - Judge(s): MJC DSO CDS
    - Lower Court No. 00-443522
    - View Docket Sheet

- 12
- 315684
- - - LIEM NGO V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Dissenting
    - Case Type: Tax Tribunal
  - - Judge(s): DSO
    - Lower Court No. 00-443522
    - View Docket Sheet

- 13
- 317171
- - - JOHN MASELLI V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Authored - Published
    - Case Type: Tax Tribunal
  - - Judge(s): MJC DSO CDS
    - Lower Court No. 00-448648
    - View Docket Sheet

- 14
- 317171
- - - JOHN MASELLI V DEPARTMENT OF TREASURY
    - Release Date: 9/9/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Dissenting
    - Case Type: Tax Tribunal
  - - Judge(s): DSO
    - Lower Court No. 00-448648
    - View Docket Sheet

- 15
- 314941
- - - PAMELA ANDERSON V CITY OF INKSTER
    - Release Date: 8/29/2014
    - COA Order - Amend Prior Opinion
  - - Judge(s): JEM, DSO, MJR
    - View Docket Sheet

- 16
- 317614
- - - HOLLY KUBICKI V DALE SHARPE JR
    - Release Date: 8/28/2014
    - Lower Court: WAYNE CIRCUIT COURT
    - COA Opinion - Per Curiam - Published
    - Case Type: Custody
  - - Judge(s): ELG DAS AK
    - Lower Court No. 05-551010-DS
    - View Docket Sheet

- 17
- 309328
- - - WILLIAM CODY V PROGRESSIVE MICHIGAN INSURANCE COMPANY
    - Release Date: 8/26/2014
    - COA Order - Reconsideration - Grant - Vacate Opinion
  - - Judge(s): MJK, MJC, KFH
    - View Docket Sheet

- 18
- 309328
- - - WILLIAM CODY V PROGRESSIVE MICHIGAN INSURANCE COMPANY
    - Release Date: 8/26/2014
    - COA Order - Reconsideration - Grant - Vacate Opinion
  - - Judge(s): MJK, MJC, KFH
    - View Docket Sheet

- 19
- 312803
- - - MAYOR OF CADILLAC V JIM BLACKBURN
    - Release Date: 8/26/2014
    - Lower Court: WEXFORD CIRCUIT COURT
    - COA Opinion - Per Curiam - Published
    - Case Type: Civil Miscellaneous
  - - Judge(s): MJR JEM KFK
    - Lower Court No. 2011-023578-CZ
    - View Docket Sheet

- 20
- 315082
- - - FEDERAL HOME LOAN MORTGAGE ASSN V MICHAEL R KELLEY
    - Release Date: 8/26/2014
    - COA Order - Reconsideration - Grant - Vacate Opinion
  - - Judge(s): SLB, DAS, JMB
    - View Docket Sheet

- 21
- 315082
- - - FEDERAL HOME LOAN MORTGAGE ASSN V MICHAEL R KELLEY
    - Release Date: 8/26/2014
    - Lower Court: INGHAM CIRCUIT COURT
    - COA Opinion - On Reconsideration - Per Curiam - Published
    - Case Type: District Court Appeal
  - - Judge(s): SLB DAS JMB
    - Lower Court No. 12-000885-AV
    - View Docket Sheet

- 22
- 315630
- - - TAMMI ATTALA V LARRY ORCUTT
    - Release Date: 8/26/2014
    - Lower Court: KENT CIRCUIT COURT
    - COA Opinion - Authored - Published
    - Case Type: Judgment for Plaintiff
  - - Judge(s): WBM DBS MJR
    - Lower Court No. 10-006907-NO
    - View Docket Sheet

- 23
- 315630
- - - TAMMI ATTALA V LARRY ORCUTT
    - Release Date: 8/26/2014
    - Lower Court: KENT CIRCUIT COURT
    - COA Opinion - Dissenting
    - Case Type: Judgment for Plaintiff
  - - Judge(s): MJR
    - Lower Court No. 10-006907-NO
    - View Docket Sheet

- 24
- 319550
- - - THOMAS R OKRIE V STATE OF MICHIGAN
    - Release Date: 8/19/2014
    - Lower Court: COURT OF CLAIMS
    - COA Opinion - Per Curiam - Published
    - Case Type: Civil Miscellaneous
  - - Judge(s): JMB JPH KFH
    - Lower Court No. 13-000093-MK
    - View Docket Sheet

- 25
- 314302
- - - PJ HOSPITALITY INC V DEPARTMENT OF TREASURY
    - Release Date: 6/26/2014
    - Lower Court: TAX TRIBUNAL
    - COA Opinion - Per Curiam - Published After Release
    - Case Type: Tax Tribunal
  - - Judge(s): PMD ELG MJK
    - Lower Court No. 00-418352
    - View Docket Sheet